dnl Copyright (C) 2011 JoungKyun.Kim <http://oops.org>
dnl
dnl This file is part of libkrisp
dnl
dnl This program is free software: you can redistribute it and/or modify
dnl it under the terms of the GNU Lesser General Public License as published
dnl by the Free Software Foundation, either version 3 of the License, or
dnl (at your option) any later version.
dnl
dnl This program is distributed in the hope that it will be useful,
dnl but WITHOUT ANY WARRANTY; without even the implied warranty of
dnl MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
dnl GNU General Public License for more details.
dnl
dnl You should have received a copy of the GNU Lesser General Public License
dnl along with this program.  If not, see <http://www.gnu.org/licenses/>.
dnl
dnl $Id: krisp.m4.in 462 2011-05-01 15:19:42Z oops $

AC_DEFUN([AX_KRISP_WITH],
[
	if test "x$with_krisp" != "x"; then
		if test "x$with_krisp" = "xyes"; then
			krispconfig="/usr/bin/krisp-config"
		else
			krispconfig="$with_krisp"
		fi
	else
		krispconfig="/usr/bin/krisp-config"
	fi

	AC_MSG_CHECKING(for krisp-config path)
	if test ! -f "$krispconfig" || test ! -x "$krispconfig"; then
		if test $krisp_check_failed -eq 1; then
			AC_MSG_ERROR(can't find $krispconfig)
		else
			krispconfig=
			AC_MSG_RESULT([not found])
		fi
	else
		AC_MSG_RESULT([$krispconfig])
	fi
])

AC_DEFUN([AX_KRISP_HEADER],
[
	#
	# krisp header check
	#
	KRISP_INCLUDES="`$krispconfig --includes 2> /dev/null`"
	if test -z "$KRISP_INCLUDES"; then
		KRISP_INCLUDES="`$krispconfig --defs 2> /dev/null | sed 's/[[ ]]*-D[[^ ]]*//g'`"
	fi

	ret_cppflags=0
	for check_cppflags in $CPPFLAGS
	do
		test -z "$KRISP_INCLUDES" && break

		if test "$check_cppflags" = "$KRISP_INCLUDES"; then
			ret_cppflags=1
			break
		fi
	done
	test $ret_cppflags -eq 0 && CPPFLAGS="$KRISP_INCLUDES $CPPFLAGS"
	AC_CHECK_HEADERS(krisp.h)
	if test "$ac_cv_header_krisp_h" != "yes"; then
		AC_MSG_ERROR([You must need krisp.h header file])
	fi
])

AC_DEFUN([AX_KRISP_LD],
[
	#
	# krisp library check
	#
	KRISP_LDFLAGS="`$krispconfig --ldflags 2> /dev/null`"

	#
	# for compatibility
	#
	if test -z "$KRISP_LDFLAGS"; then
		KRISP_LDFLAGS="`$krispconfig --libs 2> /dev/null | sed 's/[[[:space:]]]*-l.*//g'`"
	fi

	krisp_OLD_LDFLAGS="$LDFLAGS"
	LDFLAGS="$KRISP_LDFLAGS"
	AC_CHECK_LIB(
		krisp, ip2long, [
			AC_DEFINE(
				[HAVE_LIBKRISP], 1,
				[Define to 1 if you have the `krisp' library (-lkrisp).])
			LIBS="`$krispconfig --libs 2> /dev/null` $LIBS"
		],[
			if test $krisp_check_failed -eq 1; then
				AC_MSG_ERROR([Can't not found `krisp' library (-lkrisp)])
			fi
		]
	)
	LDFLAGS="$krisp_OLD_LDFLAGS"

	ret_ldflags=0
	for check_ldflags in $LDFLAGS
	do
		test -z "$KRISP_LDFLAGS" && break

		if test "$check_ldflags" = "$KRISP_LDFLAGS"; then
			ret_ldflags=1
			break
		fi
	done

	test $ret_ldflags -eq 0 && LDFLAGS="$KRISP_LDFLAGS $LDFLAGS"
])

AC_DEFUN([AX_KRISP_LIBTOOL],
[
	#
	# krisp library check
	#
	AC_MSG_CHECKING(for ip2long in -lkrisp)

	KRISP_LIBS="`$krispconfig --link-libtool 2> /dev/null`"
	if test -z "$KRISP_LIBS"; then
		KRISP_LIBS="`$krispconfig --libs 2> /dev/null`"
	fi

	if test "x$KRISP_LIBS" = "x"; then
		AC_MSG_RESULT([no])
		if test $krisp_check_failed -eq 1; then
			AC_MSG_ERROR([Can't not found krisp libtool library (libkrisp.la)])
		fi
	else
		AC_MSG_RESULT([yes])
		LIBS="$KRISP_LIBS $LIBS"
		AC_DEFINE(
			[HAVE_LIBKRISP], 1,
			[Define to 1 if you have the `krisp' library (-lkrisp).])
	fi
])

dnl
dnl Usage AX_KRISP
dnl     AX_KRISP([library type],[stop on failed])
dnl         library type : ld or libtool
dnl         stop on failed : 1 => stop, 0 => continue
dnl
dnl     AX_KRISP([library type])
dnl     AX_KRISP(1)
dnl
dnl     no argument on AX_KRISP
dnl         library type   = ld
dnl         stop on failed = 0
dnl
AC_DEFUN([AX_KRISP],
[
	ax_krisp_argc=$#
	krisp_check_failed=0

	if test $ax_krisp_argc -gt 0; then
		ax_krisp_first_arg=$1
		ax_krisp_second_arg=$2
	fi

	if test $ax_krisp_argc -gt 0; then
		if test $ax_krisp_argc -eq 2; then
			if test "$ax_krisp_first_arg" = "libtool"; then
				krisp_ld_mode="libtool"
			elif test "$ax_krisp_first_arg" = "ld"; then
				krisp_ld_mode="ld"
			else
				AC_MSG_ERROR([Unsupported link type on AX KRISP macro])
			fi

			if test $ax_krisp_second_arg -eq 1; then
				krisp_check_failed=1
			fi
		elif test $ax_krisp_argc -eq 1; then
			if test "$ax_krisp_first_arg" = "libtool"; then
				krisp_ld_mode="libtool"
			elif test "$ax_krisp_first_arg" = "ld"; then
				krisp_ld_mode="ld"
			elif test $ax_krisp_first_arg -eq 1 || test $ax_krisp_first_arg -eq 0 ; then
				krisp_check_failed=$ax_krisp_first_arg
			else
				AC_MSG_ERROR([Unsupported argument value on AX KRISP macro])
			fi
		else
			AC_MSG_ERROR([So many arguments on AX KRISP macro])
		fi
	fi

	AC_ARG_WITH(krisp,
		[  --with-krisp=PATH       path of krisp-config [[default: /usr/bin/krisp-config]]])

	if test "x$with_krisp" != "xno"; then
		AX_KRISP_WITH

		if test "$krisp_ld_mode" = "libtool"; then
			AX_KRISP_LIBTOOL
		else
			AX_KRISP_LD
		fi
		AX_KRISP_HEADER
	else
		if test $krisp_check_failed -eq 1; then
			AC_MSG_ERROR([--without-krisp doesn't permit])
		fi
	fi
])
